Fix the mazehint log so it works.
[open-adventure.git] / score.c
diff --git a/score.c b/score.c
index bf47792a5125ab833fdd9deb6c2cf42c00598e9f..645a35e96a132345e6dd512496d87c9adad9d193 100644 (file)
--- a/score.c
+++ b/score.c
@@ -7,10 +7,11 @@
  * scoring and wrap-up
  */
 
-void score(long mode)
-/* mode is <0 if scoring, >0 if quitting, =0 if died or won */
+void score(enum termination mode)
+/* mode is 'scoregame' if scoring, 'quitgame' if quitting, 'endgame' if died
+ * or won */
 {
-    long i, k, score = 0, mxscor = 0;
+    long score = 0, mxscor = 0;
 
     /*  The present scoring algorithm is as follows:
      *     Objective:          Points:        Present total possible:
@@ -33,14 +34,14 @@ void score(long mode)
 
     /*  First tally up the treasures.  Must be in building and not broken.
      *  Give the poor guy 2 points just for finding each treasure. */
-    for (i=MINTRS; i<=MAXTRS; i++) {
+    for (long i=MINTRS; i<=MAXTRS; i++) {
        if(object_descriptions[i].inventory != 0) {
-           k=12;
+           long k=12;
            if(i == CHEST)k=14;
            if(i > CHEST)k=16;
            if(game.prop[i] >= 0)
                score += 2;
-           if(game.place[i] == 3 && game.prop[i] == 0)
+           if(game.place[i] == LOC_BUILDING && game.prop[i] == 0)
                score += k-2;
            mxscor += k;
        }
@@ -54,7 +55,8 @@ void score(long mode)
      *  mundane exits or 133, 134, 135 if he blew it (so to speak). */
     score += (MAXDIE-game.numdie)*10;
     mxscor += MAXDIE*10;
-    if(mode == 0)score += 4;
+    if(mode == endgame)
+       score += 4;
     mxscor += 4;
     if(game.dflag != 0)score += 25;
     mxscor += 25;
@@ -73,7 +75,7 @@ void score(long mode)
     mxscor += 45;
 
     /* Did he come to Witt's End as he should? */
-    if(game.place[MAGZIN] == 108)
+    if(game.place[MAGZIN] == LOC_WITTSEND)
        score += 1;
     mxscor += 1;
 
@@ -82,7 +84,7 @@ void score(long mode)
     mxscor += 2;
 
     /* Deduct for hints/turns/saves. Hints < 4 are special; see database desc. */
-    for (i=1; i<=HNTMAX; i++) {
+    for (long i=1; i<=HNTMAX; i++) {
        if(game.hinted[i])
            score=score-HINTS[i][2];
     }
@@ -93,32 +95,32 @@ void score(long mode)
     score=score-game.trnluz-game.saved;
 
     /* Return to score command if that's where we came from. */
-    if(mode < 0) {
+    if(mode == scoregame) {
        SETPRM(1,score,mxscor);
        SETPRM(3,game.turns,game.turns);
-       RSPEAK(ARB_259);
+       RSPEAK(GARNERED_POINTS);
        return;
     }
 
     /* that should be good enough.  Let's tell him all about it. */
     if(score+game.trnluz+1 >= mxscor && game.trnluz != 0)
-       RSPEAK(ARB_242);
+       RSPEAK(TOOK_LONG);
     if(score+game.saved+1 >= mxscor && game.saved != 0)
-       RSPEAK(ARB_143);
+       RSPEAK(WITHOUT_SUSPENDS);
     SETPRM(1,score,mxscor);
     SETPRM(3,game.turns,game.turns);
-    RSPEAK(ARB_262);
-    for (i=1; i<=CLSSES; i++) {
+    RSPEAK(TOTAL_SCORE);
+    for (long i=1; i<=(long)CLSSES; i++) {
        if(CVAL[i] >= score) {
            newspeak(class_messages[i]);
            i=CVAL[i]+1-score;
            SETPRM(1,i,i);
-           RSPEAK(ARB_263);
+           RSPEAK(NEXT_HIGHER);
            exit(0);
        }
     }
-    RSPEAK(ARB_265);
-    RSPEAK(ARB_264);
+    RSPEAK(OFF_SCALE);
+    RSPEAK(NO_HIGHER);
     exit(0);
 
 }